## 关键词对照

见词法分析器开头中英对照部分

## 标识符中文化

- ps1, ps2

  primary and secondary interpreter prompt strings。即“提示符1、2”

- REPL

  Read-eval-print loop 交互

- is_close

  Check if the given 源码 is closed, which means each '{' has a matched '}' 括号已配对

- unclosed

  比如`func a`，未闭合的

- `<STDIN>`

  【标准输入】

- keyword

  关键词。“关键字”不妥，不仅因为 word 本身义为“词”，而且的确不限于“字”。

## 报错信息

面向用户的信息中, 一些术语不需与实现代码中的一致, 而以用户易于理解为准

| 中         | 英   | 例子                      |
|-----------|-----|-------------------------|
| index     | 索引  | list index out of range |
| Attribute | 属性  | AttributeError          |

### 语法相关中英对照术语表

| 中                              | 英                |
|--------------------------------|------------------|
| 主体                             | body             |
| 以下暂留作确认之用，基本在 `木兰/分析器/语法成分.py` |                  |
| 注水声明列表                         | stmt_list        |
| 声明列表                           | stmt_list_       |
| 声明                             | stmt             |
| 全局声明                           | declaration      |
| 引用                             | using            |
| 表达式                            | expr             |
| 二元表达式                          | bin_expr         |
| 一元表达式                          | unary_expr       |
| 表达式前缀                          | prefix_expr      |
| 生成表达式                          | yield_expr       |
| 形参列表                           | param_list       |
| 形参                             | param            |
| 实参部分                           | arguments        |
| 各实参                            | args             |
| 实参                             | arg              |
| 变量                             | var              |
| 名称                             | name             |
| 赋值                             | assign           |
| 块                              | block            |
| 混合                             | compound         |
| 类型定义                           | type_define      |
| 类型主体                           | type_body        |
| 各基准类                           | bases            |
| 各类型内声明                         | type_stmts       |
| 类型内声明                          | type_stmt        |
| 操作符                            | operator         |
| 操作数                            | op_arg           |
| 字符串                            | strlit           |
| 字符串字面量                         | STRING_LITERAL   |
| 对于声明                           | for_stmt         |
| 遍历范围                           | loop_range       |
| 迭代器                            | iterator         |
| 范围表达式                          | range_expr       |
| 点点                             | DOTDOT           |
| 增量赋值                           | aug(ment)_assign |
| 首要表达式                          | primary_expr     |
| 各表达式                           | exprs            |
| 片                              | slice            |
| 键值对                            | kv_pair          |
| 字典表达式                          | dict_expr        |
| 栈                          | frame                |
| 跟踪                          | trace               |
| 自身                           | self               |
| 类型名称                           | type_name        |
| 类型列表                           | type_list        |
| 试试声明                           | try_stmt         |
| 抛出声明                           | throw_stmt       |
| 顺便处理                           | withitem         |
| 各接手声明                          | catch_stmts      |
| 接手声明                           | catch_stmt       |
| 善后声明                           | final_stmt       |